==> open-cluster-management-policy-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/PolicyTemplateFluent.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PolicyTemplateFluent<A extends PolicyTemplateFluent<A>> extends BaseFluent<A>{
  public PolicyTemplateFluent() {
  }
  public PolicyTemplateFluent(PolicyTemplate instance) {
    instance = (instance != null ? instance : new PolicyTemplate());

    if (instance != null) {
      this.withObjectDefinition(instance.getObjectDefinition());
      this.withObjectDefinition(instance.getObjectDefinition());
    }
  }
  private Map<String,Object> objectDefinition;
  public A addToObjectDefinition(String key,Object value) {
    if(this.objectDefinition == null && key != null && value != null) { this.objectDefinition = new LinkedHashMap(); }
    if(key != null && value != null) {this.objectDefinition.put(key, value);} return (A)this;
  }
  public A addToObjectDefinition(Map<String,Object> map) {
    if(this.objectDefinition == null && map != null) { this.objectDefinition = new LinkedHashMap(); }
    if(map != null) { this.objectDefinition.putAll(map);} return (A)this;
  }
  public A removeFromObjectDefinition(String key) {
    if(this.objectDefinition == null) { return (A) this; }
    if(key != null && this.objectDefinition != null) {this.objectDefinition.remove(key);} return (A)this;
  }
  public A removeFromObjectDefinition(Map<String,Object> map) {
    if(this.objectDefinition == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.objectDefinition != null){this.objectDefinition.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getObjectDefinition() {
    return this.objectDefinition;
  }
  public <K,V>A withObjectDefinition(Map<String,Object> objectDefinition) {
    if (objectDefinition == null) { this.objectDefinition =  null;} else {this.objectDefinition = new LinkedHashMap(objectDefinition);} return (A) this;
  }
  public boolean hasObjectDefinition() {
    return this.objectDefinition != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PolicyTemplateFluent that = (PolicyTemplateFluent) o;
    if (!java.util.Objects.equals(objectDefinition, that.objectDefinition)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(objectDefinition,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (objectDefinition != null && !objectDefinition.isEmpty()) { sb.append("objectDefinition:"); sb.append(objectDefinition); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-policy-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/PolicyTemplateFluent.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PolicyTemplateFluent<A extends PolicyTemplateFluent<A>> extends BaseFluent<A>{
  public PolicyTemplateFluent() {
  }
  
  public PolicyTemplateFluent(PolicyTemplate instance) {
    this.copyInstance(instance);
  }
  private Map<String,Object> objectDefinition;
  
  protected void copyInstance(PolicyTemplate instance) {
    instance = (instance != null ? instance : new PolicyTemplate());
  
    if (instance != null) {
        this.withObjectDefinition(instance.getObjectDefinition());
        this.withObjectDefinition(instance.getObjectDefinition());
      }
  }
  
  public A addToObjectDefinition(String key,Object value) {
    if(this.objectDefinition == null && key != null && value != null) { this.objectDefinition = new LinkedHashMap(); }
    if(key != null && value != null) {this.objectDefinition.put(key, value);} return (A)this;
  }
  
  public A addToObjectDefinition(Map<String,Object> map) {
    if(this.objectDefinition == null && map != null) { this.objectDefinition = new LinkedHashMap(); }
    if(map != null) { this.objectDefinition.putAll(map);} return (A)this;
  }
  
  public A removeFromObjectDefinition(String key) {
    if(this.objectDefinition == null) { return (A) this; }
    if(key != null && this.objectDefinition != null) {this.objectDefinition.remove(key);} return (A)this;
  }
  
  public A removeFromObjectDefinition(Map<String,Object> map) {
    if(this.objectDefinition == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.objectDefinition != null){this.objectDefinition.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getObjectDefinition() {
    return this.objectDefinition;
  }
  
  public <K,V>A withObjectDefinition(Map<String,Object> objectDefinition) {
    if (objectDefinition == null) { this.objectDefinition =  null;} else {this.objectDefinition = new LinkedHashMap(objectDefinition);} return (A) this;
  }
  
  public boolean hasObjectDefinition() {
    return this.objectDefinition != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PolicyTemplateFluent that = (PolicyTemplateFluent) o;
    if (!java.util.Objects.equals(objectDefinition, that.objectDefinition)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(objectDefinition,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (objectDefinition != null && !objectDefinition.isEmpty()) { sb.append("objectDefinition:"); sb.append(objectDefinition); }
    sb.append("}");
    return sb.toString();
  }
  

}
